<a id="plugins.aea-cli-benchmark.aea_cli_benchmark.case_agent_construction_time.case"></a>

# plugins.aea-cli-benchmark.aea`_`cli`_`benchmark.case`_`agent`_`construction`_`time.case

Check amount of time and mem for agent setup.

<a id="plugins.aea-cli-benchmark.aea_cli_benchmark.case_agent_construction_time.case.run"></a>

#### run

```python
def run(agents: int) -> List[Tuple[str, Union[int, float]]]
```

Check construction time and memory usage.

